@@ -107,10 +107,11 @@ class Remove_duplicate_time(object):
             if len(new_stroke) > 0:
                 new_pointlist.append(new_stroke)
         # Make sure there are no duplicates
-        times = [point['time'] for stroke in pointlist for point in stroke]
+        times = [point['time'] for stroke in new_pointlist for point in stroke]
         assert len(times) == len(set(times)), \
             ("The list of all times in Remove_duplicate_time has %i values, "
-             "but the set has %i values.") % (len(times), len(set(times)))
+             "but the set has %i values: %s --- %s") % \
+            (len(times), len(set(times), pointlist, new_pointlist))
         handwritten_data.set_pointlist(new_pointlist)
 
 
